@@ -13,6 +13,7 @@ import pathlib
 from ann_benchmarks.results import get_result_filename
 from ann_benchmarks.algorithms.definitions import get_run_groups
 
+
 def aggregate_outputs(files, clients):
     different_attrs = set([f.split('client')[0] for f in files])
     groups = [[f + f'client_{i}.hdf5' for i in range(1, clients + 1)] for f in different_attrs]
@@ -20,42 +21,43 @@ def aggregate_outputs(files, clients):
     if len(different_attrs) * clients > len(files):
         print(f'missing files! got {len(files)} but expected {len(different_attrs) * clients}')
         print('got files:')
-        [print('\t'+f) for f in files]
+        [print('\t' + f) for f in files]
         print('probably missing files:')
-        [[print('\t'+f) for f in g if f not in files] for g in groups]
+        [[print('\t' + f) for f in g if f not in files] for g in groups]
         assert False
     elif len(different_attrs) * clients < len(files):
         print(f'too many files! got {len(files)} but expected {len(different_attrs) * clients}')
         print('got files:')
-        [print('\t'+f) for f in files]
+        [print('\t' + f) for f in files]
         print('probably unnecessary files:')
-        [print('\t'+f) for f in files if len([g for g in groups if f in g]) == 0]
+        [print('\t' + f) for f in files if len([g for g in groups if f in g]) == 0]
         raise False
-        
+
     for group in groups:
         fn = group[0].split('client')[0][:-1] + '.hdf5'
         f = h5py.File(fn, 'w')
-        
+
         fs = [h5py.File(fi, 'r') for fi in group]
         for k, v in fs[0].attrs.items():
             f.attrs[k] = v
         f.attrs["best_search_time"] = average([fi.attrs["best_search_time"] for fi in fs])
         f.attrs["candidates"] = average([fi.attrs["candidates"] for fi in fs])
-        
+
         times = f.create_dataset('times', fs[0]['times'].shape, 'f')
         neighbors = f.create_dataset('neighbors', fs[0]['neighbors'].shape, 'i')
         distances = f.create_dataset('distances', fs[0]['distances'].shape, 'f')
         num_tests = len(times)
-        
+
         for i in range(num_tests):
             neighbors[i] = [n for n in fs[0]['neighbors'][i]]
             distances[i] = [n for n in fs[0]['distances'][i]]
             times[i] = average([fi['times'][i] for fi in fs])
-        
+
         [fi.close() for fi in fs]
         [os.remove(fi) for fi in group]
         f.close()
 
+
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(
         formatter_class=argparse.ArgumentDefaultsHelpFormatter)
@@ -96,12 +98,6 @@ if __name__ == "__main__":
         metavar='NAME',
         help='user name for connection',
         default=None)
-    parser.add_argument(
-        '--full-flow-clients',
-        type=str,
-        metavar='NUM',
-        help='total number of clients running in parallel to execute a full flow (defaults to 0)',
-        default="0")
     parser.add_argument(
         '--build-clients',
         type=str,
@@ -159,7 +155,7 @@ if __name__ == "__main__":
     if isredis:
         redis = RedisCluster if args.cluster else Redis
         redis = redis(host=args.host, port=int(args.port), password=args.auth, username=args.user)
-    
+
     if args.run_group is not None:
         run_groups = [args.run_group]
     else:
@@ -174,71 +170,28 @@ if __name__ == "__main__":
     if args.force:      base += ' --force'
     if args.cluster:    base += ' --cluster'
 
-    base_flow = base + ' --runs {} --total-clients {}'.format(args.runs, args.full_flow_clients)
     base_build = base + ' --build-only --total-clients ' + args.build_clients
     base_test = base + ' --test-only --runs {} --total-clients {}'.format(args.runs, args.test_clients)
     outputsdir = "{}/{}".format(workdir, get_result_filename(args.dataset, args.count))
     outputsdir = os.path.join(outputsdir, args.algorithm)
     if not os.path.isdir(outputsdir):
         os.makedirs(outputsdir)
-    results_dict = {}
-    flow_clients = int(args.full_flow_clients)
-    build_clients = int(args.build_clients)
-    test_clients = int(args.test_clients)
-    if flow_clients >- 0 :
-        queriers = [Process(target=os.system, args=(base_flow + ' --client-id ' + str(i),)) for i in range(1, int(args.full_flow_clients) + 1)]
-        test_stats = set()
-        watcher = PatternMatchingEventHandler(["*.hdf5"], ignore_directories=True )
-        def on_created_or_modified(event):
-            test_stats.add(event.src_path)
-        watcher.on_created = on_created_or_modified
-        watcher.on_modified = on_created_or_modified
-        observer = Observer()
-        observer.schedule(watcher, workdir, True)
-        observer.start()
-        t0 = time.time()
-        for querier in queriers: querier.start()
-        for querier in queriers: querier.join()
-        query_time = time.time() - t0
-        print(f'total test time: {query_time}')
-        observer.stop()
-        observer.join()
-        results_dict["query"] = {"total_clients":args.full_flow_clients, "test_time": query_time }
-        print(f'summarizing {int(args.full_flow_clients)} clients data ({len(test_stats)} files into {len(test_stats) // int(args.full_flow_clients)})...')
-        aggregate_outputs(test_stats, int(args.full_flow_clients))
-        print('done!')
+    results_dicts = []
 
-    if build_clients > 0 and test_clients == 0:
-        clients = [Process(target=os.system, args=(base_build + ' --client-id ' + str(i),)) for i in range(1, int(args.build_clients) + 1)]
+    # skipping aggregation if using one tester
+    if int(args.test_clients) > 1:
+        test_stats_files = set()
+        watcher = PatternMatchingEventHandler(["*.hdf5"], ignore_directories=True)
 
-        t0 = time.time()
-        for client in clients: client.start()
-        for client in clients: client.join()
-        total_time = time.time() - t0
-        print(f'total build time: {total_time}\n\n')
 
-        fn = os.path.join(outputsdir, 'build_stats')
-        f = h5py.File(fn, 'w')
-        f.attrs["build_time"] = total_time
-        print(fn)
-        index_size = -1
-        if isredis:
-            if not args.cluster: # TODO: get total size from all the shards
-                index_size = redis.ft('ann_benchmark').info()['vector_index_sz_mb']
-            f.attrs["index_size"] = float(index_size)
-        f.close()
-        results_dict["build"] = {"total_clients":args.build_clients, "build_time": total_time, "vector_index_sz_mb": index_size }
-
-    elif test_clients > 0 and build_clients == 0:
-        queriers = [Process(target=os.system, args=(base_test + ' --client-id ' + str(i),)) for i in range(1, int(args.test_clients) + 1)]
-        test_stats = set()
-        watcher = PatternMatchingEventHandler(["*.hdf5"], ignore_directories=True )
         def on_created_or_modified(event):
             test_stats_files.add(event.src_path)
+
+
         watcher.on_created = on_created_or_modified
         watcher.on_modified = on_created_or_modified
         observer = Observer()
-        observer.schedule(watcher, workdir, True)
+        observer.schedule(watcher, outputsdir)
         observer.start()
 
     for run_group in run_groups:
@@ -250,7 +203,8 @@ if __name__ == "__main__":
         curr_base_test = base_test + ' --run-group ' + run_group
 
         if int(args.build_clients) > 0:
-            clients = [Process(target=os.system, args=(curr_base_build + ' --client-id ' + str(i),)) for i in range(1, int(args.build_clients) + 1)]
+            clients = [Process(target=os.system, args=(curr_base_build + ' --client-id ' + str(i),)) for i in
+                       range(1, int(args.build_clients) + 1)]
 
             t0 = time.time()
             for client in clients: client.start()
@@ -264,20 +218,22 @@ if __name__ == "__main__":
             print(fn)
             index_size = -1
             if isredis:
-                if not args.cluster: # TODO: get total size from all the shards
-                    index_size = float(redis.ft('ann_benchmark').info()['vector_index_sz_mb'])*1024
+                if not args.cluster:  # TODO: get total size from all the shards
+                    index_size = float(redis.ft('ann_benchmark').info()['vector_index_sz_mb']) * 1024
                 f.attrs["index_size"] = index_size
             f.close()
-            results_dict["build"] = {"total_clients":args.build_clients, "build_time": total_time, "vector_index_sz_mb": index_size }
+            results_dict["build"] = {"total_clients": args.build_clients, "build_time": total_time,
+                                     "vector_index_sz_mb": index_size}
 
         if int(args.test_clients) > 0:
-            queriers = [Process(target=os.system, args=(curr_base_test + ' --client-id ' + str(i),)) for i in range(1, int(args.test_clients) + 1)]
+            queriers = [Process(target=os.system, args=(curr_base_test + ' --client-id ' + str(i),)) for i in
+                        range(1, int(args.test_clients) + 1)]
             t0 = time.time()
             for querier in queriers: querier.start()
             for querier in queriers: querier.join()
             query_time = time.time() - t0
             print(f'total test time: {query_time}')
-            results_dict["query"] = {"total_clients":args.test_clients, "test_time": query_time }
+            results_dict["query"] = {"total_clients": args.test_clients, "test_time": query_time}
 
         results_dicts.append(results_dict)
 
@@ -285,11 +241,12 @@ if __name__ == "__main__":
     if int(args.test_clients) > 1:
         observer.stop()
         observer.join()
-        print(f'summarizing {int(args.test_clients)} clients data ({len(test_stats_files)} files into {len(test_stats_files) // int(args.test_clients)})...')
+        print(
+            f'summarizing {int(args.test_clients)} clients data ({len(test_stats_files)} files into {len(test_stats_files) // int(args.test_clients)})...')
         aggregate_outputs(test_stats_files, int(args.test_clients))
         print('done!')
 
-    elif args.json_output != "":
-        with open(args.json_output,"w")as json_out_file:
+    if args.json_output != "":
+        with open(args.json_output, "w") as json_out_file:
             print(f'storing json result into: {args.json_output}')
-            json.dump(results_dict,json_out_file)
+            json.dump(results_dict, json_out_file)
